/*============================================================================
  File:     PartialRestore.sql

  Summary:  This script shows how to perform a
			partial restore from scratch

  Date:     June 2010

  SQL Server Versions:
		10.0.2531.00 (SS2008 SP1)
		9.00.4035.00 (SS2005 SP3)
------------------------------------------------------------------------------
  Written by Paul S. Randal, SQLskills.com

  (c) 2011, SQLskills.com. All rights reserved.

  For more scripts and sample code, check out 
    http://www.SQLskills.com

  You may alter this code for your own *non-commercial* purposes. You may
  republish altered code as long as you include this copyright and give due
  credit, but you must obtain prior permission before blogging this code.
  
  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF 
  ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED 
  TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
  PARTICULAR PURPOSE.
============================================================================*/

USE master;
GO

-- Make sure we have backups to restore from
BACKUP DATABASE SalesDB TO
	DISK = N'D:\SQLskills\SalesDBBackup.bak'
	WITH INIT, STATS = 10;
GO

BACKUP LOG SalesDB TO
	DISK = N'D:\SQLskills\SalesDBBackup_Log.bak'
	WITH INIT, STATS = 10;
GO

-- Disaster strikes!
DROP DATABASE SalesDB;
GO

-- How to restore as fast as possible?

-- Start with the PRIMARY filegroup
RESTORE DATABASE SalesDB
    FILEGROUP = 'PRIMARY'
FROM DISK = 'D:\SQLskills\SalesDBBackup.bak'
WITH PARTIAL, NORECOVERY, STATS;
GO

-- Bring the OLTP filegroup online
RESTORE DATABASE SalesDB
    FILEGROUP = 'SalesDBSales2012'
FROM DISK = 'D:\SQLskills\SalesDBBackup.bak'
WITH NORECOVERY, STATS;
GO

-- Restore transaction log backups
RESTORE LOG SalesDB
FROM DISK = N'D:\SQLskills\SalesDBBackup_Log.bak'
WITH NORECOVERY, STATS;
GO

-- Bring the database online
RESTORE DATABASE SalesDB WITH RECOVERY;
GO

-- Online piecemeal restore other filegroups
-- at our leisure
SELECT [name], [state_desc] FROM
	SalesDB.sys.database_files;
GO

-- Beware of queries that need to access all
-- filegroups
SELECT COUNT (*) FROM SalesDB.dbo.Sales
WHERE CustomerID = 1440;
GO