/*============================================================================
  File:     PartitionSalesDB.sql

  Summary:  This script sets up the SalesDB
			database for the PDA demo

  Date:     June 2009

  SQL Server Versions:
		10.0.2531.00 (SS2008 SP1)
		9.00.4035.00 (SS2005 SP3)
------------------------------------------------------------------------------
  Written by Paul S. Randal, SQLskills.com

  (c) 2011, SQLskills.com. All rights reserved.

  For more scripts and sample code, check out 
    http://www.SQLskills.com

  You may alter this code for your own *non-commercial* purposes. You may
  republish altered code as long as you include this copyright and give due
  credit, but you must obtain prior permission before blogging this code.
  
  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF 
  ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED 
  TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
  PARTICULAR PURPOSE.
============================================================================*/

-- Start it all running and then explain
-- what's going on...

USE MASTER;
GO

IF DATABASEPROPERTYEX ('SalesDB_Snapshot', 'Version') > 0
	DROP DATABASE SalesDB_Snapshot;
GO

-- Get SalesDB from our resources page...

-- Make sure we start with a clean database
RESTORE DATABASE SalesDB
	FROM DISK = N'D:\SQLskills\DemoBackups\SalesDBOriginal.bak'
WITH STATS = 10, REPLACE;
GO

USE SalesDB;
GO

-- Repartition the big sales table onto
-- a new filegroup

-- Create the filegroups
ALTER DATABASE SalesDB 
	ADD FILEGROUP SalesDBSales2012
ALTER DATABASE SalesDB 
	ADD FILEGROUP SalesDBSales2011
ALTER DATABASE SalesDB 
	ADD FILEGROUP SalesDBSales2010
ALTER DATABASE SalesDB 
	ADD FILEGROUP SalesDBSales2009
GO

-- And add a file in each
ALTER DATABASE SalesDB ADD FILE
	(NAME = N'SalesDBSales2012',
	FILENAME = N'C:\SQLskills\SalesDBSales2012.ndf', 
	SIZE = 100,
	MAXSIZE = 120,
	FILEGROWTH = 10)
TO FILEGROUP SalesDBSales2012

ALTER DATABASE SalesDB ADD FILE
	(NAME = N'SalesDBSales2011',
	FILENAME = N'C:\SQLskills\SalesDBSales2011.ndf', 
	SIZE = 100,
	MAXSIZE = 120,
	FILEGROWTH = 10)
TO FILEGROUP SalesDBSales2011

ALTER DATABASE SalesDB ADD FILE
	(NAME = N'SalesDBSales2010',
	FILENAME = N'C:\SQLskills\SalesDBSales2010.ndf', 
	SIZE = 100,
	MAXSIZE = 120,
	FILEGROWTH = 10)
TO FILEGROUP SalesDBSales2010

ALTER DATABASE SalesDB ADD FILE
	(NAME = N'SalesDBSales2009',
	FILENAME = N'C:\SQLskills\SalesDBSales2009.ndf', 
	SIZE = 100,
	MAXSIZE = 120,
	FILEGROWTH = 10)
TO FILEGROUP SalesDBSales2009
GO

-- Create the partitioning metadata
CREATE PARTITION FUNCTION Sales4Partitions_PFN (INT)
AS 
RANGE RIGHT FOR VALUES (2000000,		-- 2 million
						4000000,		-- 4 million
						6000000)		-- 6 million
GO

CREATE PARTITION SCHEME [Sales4Partitions_PS]
AS 
PARTITION [Sales4Partitions_PFN] TO 
		(SalesDBSales2009,
		SalesDBSales2010, 
		SalesDBSales2011,
		SalesDBSales2012)
GO

-- Move the table to the new schema
-- (Takes a minute or so)
CREATE UNIQUE CLUSTERED INDEX SalesPK 
	ON Sales (SalesID)
WITH (DROP_EXISTING = ON, ONLINE = ON)
	ON Sales4Partitions_PS (SalesID)
GO

-- Check it got moved
sp_help Sales;
GO
