/*============================================================================
  File:     01CreatePageRestore.sql

  Summary:  This script creates a demo database to use in
		a page restore demo.

  Date:     June 2010

  SQL Server Versions:
		10.0.2531.00 (SS2008 SP1)
		9.00.4035.00 (SS2005 SP3)
------------------------------------------------------------------------------
  Written by Paul S. Randal, SQLskills.com

  (c) 2011, SQLskills.com. All rights reserved.

  For more scripts and sample code, check out 
    http://www.SQLskills.com

  You may alter this code for your own *non-commercial* purposes. You may
  republish altered code as long as you include this copyright and give due
  credit, but you must obtain prior permission before blogging this code.
  
  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF 
  ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED 
  TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
  PARTICULAR PURPOSE.
============================================================================*/

-- Create the database and take a full backup

USE master;
GO

IF DATABASEPROPERTY ('DemoPageRestore', 'Version') > 0
	DROP DATABASE DemoPageRestore;
GO

CREATE DATABASE DemoPageRestore;
GO

-- Set the recovery mode to full
ALTER DATABASE DemoPageRestore SET RECOVERY FULL;
GO

-- Create a table to play with.
CREATE TABLE DemoPageRestore.dbo.sales (
	salesID INT IDENTITY,
	customerID INT DEFAULT CONVERT (INT, 100000 * RAND ()),
	salesDate DATETIME DEFAULT GETDATE (),
	salesAmount MONEY);

CREATE CLUSTERED INDEX salesCI ON
	DemoPageRestore.dbo.sales (salesID);
GO

-- Populate the table
SET NOCOUNT ON;
GO

DECLARE @count INT
SELECT @count = 0
WHILE (@count < 5000)
BEGIN
	INSERT INTO DemoPageRestore.dbo.sales (salesAmount)
		VALUES (100 * RAND ());
	SELECT @count = @count + 1
END;
GO

-- Take a full backup.
BACKUP DATABASE DemoPageRestore TO
	DISK = 'C:\SQLskills\DemoPageRestore.bak'
	WITH INIT;
GO
BACKUP LOG DemoPageRestore TO
	DISK = 'C:\SQLskills\DemoPageRestore_LOG1.bak'
	WITH INIT;
GO

-- Now shutdown and zero out a page to simulate an IO error
-- Picking page (1, 158) to corrupt
-- Remember to then backup the corrupt database for Part 2
/*
BACKUP DATABASE DemoPageRestore TO
	DISK = 'C:\SQLskills\CorruptionDemoBackups\CorruptDemoPageRestore.bak';
	WITH INIT;
GO
*/